"""Common filenames and locations for topographic data, meshes and outputs.
Also includes origin for slump scenario.
"""


from os import sep
from os.path import expanduser
import sys

#Making assumptions about the location of scenario data
scenario_dir_name = 'sydney_tsunami_scenario_2006'
# original 100m data
#basename = 'sydney_2006_100' # get from Neil/Ingo (DEM or topo data)
# revised 100m data
coarsename = 'bathyland100' # get from Neil/Ingo (DEM or topo data)
# revised 25m data
#finename = 'bathyland25' # get from Neil/Ingo (DEM or topo data)
#finename = 'bathyland100' # get from Neil/Ingo (DEM or topo data)
finename = 'bathy_dem25' # get from Neil/Ingo (DEM or topo data) Wed 25 Jan

# creating easting and northing max and min for fine data - region of interest
eastingmin = 332090
eastingmax = 347500
northingmin = 6246250
northingmax = 6264100
#northingmax = 6280100

# creating easting and northing max and min for export viz purposes
#eminviz = 332000
#emaxviz = 350000
#nminviz = 6231000
#nmaxviz = 6283000

# version2
eminviz = 318000
emaxviz = 351000
nminviz = 6231000
nmaxviz = 6283000
# for harbour region
#nminviz = 6248000
#nmaxvix = 6270000
# for botany bay region
#nmaxviz = 6248000
#nminvix = 6283000

basename = 'slump_ole'

if sys.platform == 'win32':
    home = '..\..\..\..\..'     #Sandpit's parent dir
else:    
    home = expanduser('~')


#Derive subdirectories and filenames
meshdir = home+sep+scenario_dir_name+sep+'meshes'+sep
datadir = home+sep+scenario_dir_name+sep+'topographies'+sep
outputdir = home+sep+scenario_dir_name+sep+'output'+sep
#boundarydir = home+sep+scenario_dir_name+sep+'boundaries'+sep

meshname = meshdir + basename
coarsedemname = datadir + coarsename
finedemname = datadir + finename
combineddemname = datadir + 'sydneytopo'
#boundaryname = boundarydir + boundary_basename
outputname = outputdir + basename  #Used by post processing
#newoutputname = outputdir+'Combined Data v1'+sep+'d400'+sep+basename
gauge_filename = outputdir + 'sydney_gauges.xya'
gauge_outname = outputdir + 'gauges_max_output.xya'

#Georeferencing
#from pyvolution.coordinate_transforms.redfearn import degminsec2decimal_degrees
from coordinate_transforms.redfearn import degminsec2decimal_degrees

#Origin of existing dem (FIXME: Temporary measure)
#x0_origin = 314036 #original 100m data
#y0_origin = 6224951
#refzone = 56
#x0_origin = 314036.58727982 #revised 100m and 25m data
#y0_origin = 6224951.2960092
#mesh_origin = (refzone, x0_origin, y0_origin)  # input from Neil's data

# define clipping polygon
south = degminsec2decimal_degrees(-34,05,0)
north = degminsec2decimal_degrees(-33,33,0)
west = degminsec2decimal_degrees(151,1,0)
east = degminsec2decimal_degrees(151,30,0)
p0 = [south, west]
p1 = [south, east]
p2 = [north, east]
p3 = [north, west]
    
polygonall = [p0, p1, p2, p3]

dsouth = degminsec2decimal_degrees(-34,05,0)
dnorth = degminsec2decimal_degrees(-33,33,0)
dnorth1 = degminsec2decimal_degrees(-33,40,0)
dnorth2 = degminsec2decimal_degrees(-33,58,30)
dnorth3 = degminsec2decimal_degrees(-33,46,0)
dwest = degminsec2decimal_degrees(151,2,20)
deast1 = degminsec2decimal_degrees(151,20,0)
deast2 = degminsec2decimal_degrees(151,48,0)
deast3 = degminsec2decimal_degrees(151,10,0)
deast4 = degminsec2decimal_degrees(151,9,0)

dp0 = [dsouth, dwest]
dp1 = [dsouth, deast1]
dp2 = [dnorth2, deast2]
dp3 = [dnorth1, deast2]
dp4 = [dnorth, deast1]
dp5 = [dnorth, deast4]
dp6 = [dnorth3, deast3]
dp7 = [dnorth3, dwest]
dp8 = [dnorth, dwest]
    
#diffpolygonall = [dp0, dp1, dp2, dp3, dp4, dp5, dp6, dp7]
diffpolygonall = [dp0, dp1, dp2, dp3, dp4, dp5, dp6, dp7]
# to put chunk back in
#diffpolygonall = [dp0, dp1, dp2, dp3, dp4, dp8] 

#Interior regions - the Harbour - take 2
harbour_1x = degminsec2decimal_degrees(-33,51,0)
harbour_1y = degminsec2decimal_degrees(151,2,30)
harbour_12x = degminsec2decimal_degrees(-33,51,0)
harbour_12y = degminsec2decimal_degrees(151,5,0)
harbour_13x = degminsec2decimal_degrees(-33,52,15)
harbour_13y = degminsec2decimal_degrees(151,5,0)
harbour_2x = degminsec2decimal_degrees(-33,53,0)
harbour_2y = degminsec2decimal_degrees(151,17,20)
harbour_3x = degminsec2decimal_degrees(-33,47,0)
harbour_3y = degminsec2decimal_degrees(151,20,30)
#harbour_4x = degminsec2decimal_degrees(-33,48,0)
harbour_4x = degminsec2decimal_degrees(-33,47,50)
harbour_4y = degminsec2decimal_degrees(151,8,10)
#harbour_5x = degminsec2decimal_degrees(-33,49,0)
harbour_5x = degminsec2decimal_degrees(-33,48,10)
harbour_5y = degminsec2decimal_degrees(151,8,0)
harbour_6x = degminsec2decimal_degrees(-33,49,0)
harbour_6y = degminsec2decimal_degrees(151,2,30)
harbour_7x = degminsec2decimal_degrees(-33,34,30)
harbour_7y = degminsec2decimal_degrees(151,20,20)
#harbour_8x = degminsec2decimal_degrees(-33,33,30)
#harbour_8y = degminsec2decimal_degrees(151,15,0)
harbour_8x = degminsec2decimal_degrees(-33,33,30)
harbour_8y = degminsec2decimal_degrees(151,17,0)
#harbour_9x = degminsec2decimal_degrees(-33,45,30)
#harbour_9y = degminsec2decimal_degrees(151,15,0)
harbour_9x = degminsec2decimal_degrees(-33,45,30)
harbour_9y = degminsec2decimal_degrees(151,17,0)
harbour_10x = degminsec2decimal_degrees(-33,45,10)
harbour_10y = degminsec2decimal_degrees(151,11,40)
harbour_11x = degminsec2decimal_degrees(-33,45,10)
harbour_11y = degminsec2decimal_degrees(151,11,40)
harbour_14x = degminsec2decimal_degrees(-33,49,10)
harbour_14y = degminsec2decimal_degrees(151,11,40)
harbour_15x = degminsec2decimal_degrees(-33,48,55)
harbour_15y = degminsec2decimal_degrees(151,2,30)

k02 = [harbour_1x, harbour_1y]
k12 = [harbour_2x, harbour_2y]
k22 = [harbour_3x, harbour_3y]
k32 = [harbour_4x, harbour_4y]
k42 = [harbour_5x, harbour_5y]
k52 = [harbour_6x, harbour_6y]
k62 = [harbour_7x, harbour_7y]
k72 = [harbour_8x, harbour_8y]
k82 = [harbour_9x, harbour_9y]
k92 = [harbour_10x, harbour_10y]
k102 = [harbour_11x, harbour_11y]
k112 = [harbour_12x, harbour_12y]
k122 = [harbour_13x, harbour_13y]
k132 = [harbour_14x, harbour_14y]
k142 = [harbour_15x, harbour_15y]

#harbour_polygon_2 = [k02, k112, k122, k12, k22, k62, k72, k82, k92, k102, k32, k42, k52]
#harbour_polygon_2 = [k122, k12, k22, k62, k72, k102] #worked
harbour_polygon_2 = [k02, k112, k122, k12, k22, k62, k72, k82, k102, k42, k52] #worked

#Interior region - Botany Bay - take 2
bb_1x = degminsec2decimal_degrees(-34,3,0)
bb_1y = degminsec2decimal_degrees(151,2,30)
bb_10x = degminsec2decimal_degrees(-34,3,0)
bb_10y = degminsec2decimal_degrees(151,8,0)
bb_2x = degminsec2decimal_degrees(-34,3,0)
bb_2y = degminsec2decimal_degrees(151,14,0)
bb_3x = degminsec2decimal_degrees(-33,53,30)
bb_3y = degminsec2decimal_degrees(151,17,20)
bb_4x = degminsec2decimal_degrees(-33,53,0)
bb_4y = degminsec2decimal_degrees(151,8,0)
bb_5x = degminsec2decimal_degrees(-33,57,30)
bb_5y = degminsec2decimal_degrees(151,8,0)
bb_6x = degminsec2decimal_degrees(-33,57,30)
bb_6y = degminsec2decimal_degrees(151,2,30)  
bb_7x = degminsec2decimal_degrees(-33,53,30)
bb_7y = degminsec2decimal_degrees(151,12,30)  
bb_8x = degminsec2decimal_degrees(-33,55,20)
bb_8y = degminsec2decimal_degrees(151,8,0)  
bb_9x = degminsec2decimal_degrees(-33,55,20)
bb_9y = degminsec2decimal_degrees(151,12,30)  

j02 = [bb_1x, bb_1y]
j12 = [bb_2x, bb_2y]
j22 = [bb_3x, bb_3y]
j32 = [bb_4x, bb_4y]
j42 = [bb_5x, bb_5y]
j52 = [bb_6x, bb_6y]
j62 = [bb_7x, bb_7y]
j72 = [bb_8x, bb_8y]
j82 = [bb_9x, bb_9y]
j92 = [bb_10x, bb_10y]

botanybay_polygon_2 = [j92, j12, j22, j62, j82, j72, j42] # worked
#botanybay_polygon_2 = [j02, j12, j22, j32, j42, j52] # worked

# this section sets up source origin for slump scenario
# close to harbour opening (343000,6255000)
# x0 = 28964
# y0 = 30049
# around 10km harbour opening (353000,6255000)
#x0 = 38964
#y0 = 30049
# around 18km across from harbour(361000,6255000) 
#x0 = 46964
#y0 = 30049
# around 42km across from harbour(385000,6255000) 
x0 = 28964 + 42000
y0 = 30049

#revised 100m and 25m data
slump_origin = [x0+314036.58727982, y0+6224951.2960092] #Absolute UTM


# close to botany bay opening (340000,6236000)
# x0 = 25964
# y0 = 11049
# around 10km from botany bay opening (350000,6236000)
# x0 = 35964
# y0 = 11049
# around 21km from botany bay opening (361000,6236000)
#x0 = 46964
#y0 = 11049

# not used for sydney scenario, original interior regions listed though
# setting up problem area for doing just around the harbour
hsouth = degminsec2decimal_degrees(-33,54,0)
hnorth = degminsec2decimal_degrees(-33,48,0)
hwest = degminsec2decimal_degrees(151,0,0)
heast = degminsec2decimal_degrees(151,30,0)

hp0 = [hsouth, hwest]
hp1 = [hsouth, heast]
hp2 = [hnorth, heast]
hp3 = [hnorth, hwest]
polygon_h = [hp0, hp1, hp2, hp3]

#Interior regions - the Harbour - take 1
harbour_south = degminsec2decimal_degrees(-33,53,0)
harbour_north = degminsec2decimal_degrees(-33,47,0)
harbour_west = degminsec2decimal_degrees(151,5,0)
harbour_east = degminsec2decimal_degrees(151,19,0)

#harbour_south1 = degminsec2decimal_degrees(-33,53,0)
#harbour_south2 = degminsec2decimal_degrees(-33,52,0)
#harbour_north1 = degminsec2decimal_degrees(-33,45,0)
#harbour_north2 = degminsec2decimal_degrees(-33,48,0)
#harbour_west = degminsec2decimal_degrees(151,5,0)
#harbour_east = degminsec2decimal_degrees(151,19,0)

k0 = [harbour_south, harbour_west]
k1 = [harbour_south, harbour_east]
k2 = [harbour_north, harbour_east]
k3 = [harbour_north, harbour_west]    

harbour_polygon = [k0, k1, k2, k3]

# setting up problem area for doing just around Botany Bay
bsouth = degminsec2decimal_degrees(-33,56,0)
bnorth = degminsec2decimal_degrees(-34,3,0)
bwest = degminsec2decimal_degrees(151,0,0)
beast = degminsec2decimal_degrees(151,30,0)

bp0 = [bsouth, bwest]
bp1 = [bsouth, beast]
bp2 = [bnorth, beast]
bp3 = [bnorth, bwest]
polygon_bb = [bp0, bp1, bp2, bp3]

#Interior region - Botany Bay - take 1
botanybay_south = degminsec2decimal_degrees(-33,58,0)
botanybay_north = degminsec2decimal_degrees(-34,1,0)
botanybay_west = degminsec2decimal_degrees(151,5,0)
botanybay_east = degminsec2decimal_degrees(151,18,0)

j0 = [botanybay_south, botanybay_west]
j1 = [botanybay_south, botanybay_east]
j2 = [botanybay_north, botanybay_east]
j3 = [botanybay_north, botanybay_west]    

botanybay_polygon = [j0, j1, j2, j3]
